References and further reading
===============================

.. _further_reading:

Further reading
---------------

For more details and further information on continuous-variable quantum computation and Gaussian quantum information, please see the following:

.. bibliography:: references.bib
	:style: unsrt
	:labelprefix: FR
	:filter: key % "FR-"

.. _references:

References
----------

.. bibliography:: references.bib
	:cited:
	:style: unsrt
   
